
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.09

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'lib/Net/Works.pm',
    'lib/Net/Works/Address.pm',
    'lib/Net/Works/Network.pm',
    'lib/Net/Works/Role/IP.pm',
    'lib/Net/Works/Types.pm',
    'lib/Net/Works/Util.pm',
    't/Address.t',
    't/Network-splitting.t',
    't/Network.t',
    't/author-no-tabs.t',
    't/author-test-eol.t',
    't/bad-data.t',
    't/release-cpan-changes.t',
    't/release-pod-coverage.t',
    't/release-pod-linkcheck.t',
    't/release-pod-no404s.t',
    't/release-pod-spell.t',
    't/release-pod-syntax.t',
    't/release-synopsis.t'
);

notabs_ok($_) foreach @files;
done_testing;
